@@ -32,14 +32,6 @@ for mod in (PE, vtrace):
 # 0x183   DEC Alpha AXP
 
 
-def align(v, alignment):
-    remainder = v % alignment
-    if remainder == 0:
-        return v
-    else:
-        return v + (alignment - remainder)
-
-
 def parseFile(vw, filename, baseaddr=None):
     pe = PE.PE(open(filename, "rb"))
     return loadPeIntoWorkspace(vw, pe, filename=filename, baseaddr=baseaddr)
@@ -327,21 +319,12 @@ def loadPeIntoWorkspace(vw, pe, filename=None, baseaddr=None):
             # According to http://code.google.com/p/corkami/wiki/PE#section_table if SizeOfRawData is larger than VirtualSize, VS is used..
             readsize = sec.SizeOfRawData if sec.SizeOfRawData < sec.VirtualSize else sec.VirtualSize
 
-            # align the read to the FileAlignment
-            readsize = align(readsize, filealign)
-
             secoff = pe.rvaToOffset(secrva)
             secbytes = pe.readAtOffset(secoff, readsize, shortok=True)
             slen = len(secbytes)
-            if slen != readsize:
-                logger.warning("Section at offset 0x%x should have 0x%x bytes, but we only got 0x%x bytes", secoff, readsize, slen)
+            secbytes += b'\x00' * (sec.VirtualSize - slen)
 
-            if slen != align(sec.VirtualSize, secalign):
-                # pad the section up to next the SectionAlignment
-                secbytes += b'\x00' * (align(sec.VirtualSize, secalign) - slen)
-
-            slen = len(secbytes)
-            vw.addMemoryMap(secbase, mapflags, fname, secbytes)
+            slen = vw.addMemoryMap(secbase, mapflags, fname, secbytes, align=filealign)
             vw.addSegment(secbase, slen, secname, fname)
 
             # Mark dead data on resource and import data directories
