@@ -410,9 +410,9 @@ class VivisectTest(unittest.TestCase):
                                  (134553488,), (134556128,), (134559504,), (134573472,), (134554096,), (134572464,),
                                  (134575616,), (134575872,), (134575552,), (134582112,), (134561824,), (134573264,),
                                  (134561232,), (134574816,), (134547936,), (134582096,), (134552448,), (134552560,),
-                                 (134575584,), (134553216,), (134573760,), (134582064,), (134583824,), (134519952,),
-                                 (134568352,), (134519472,), (134518848,), (134518128,), (134518112,), (134518736,),
-                                 (134518304,), (134518512,), (134518480,), (134518576,), (134519376,), (134518000,),
+                                 (134575584,), (134553216,), (134573760,), (134582064,),
+                                 (134519472,), (134518848,), (134518128,), (134518112,),
+                                 (134518304,), (134518512,), (134518576,), (134518000,),
                                  (134518672,), ]
 
         }
@@ -426,7 +426,7 @@ class VivisectTest(unittest.TestCase):
                 self.fail(mesg)
 
         self.assertEqual(len(vw.getVaSetRows('CodeFragments')), 213)
-        self.assertEqual(len(vw.getVaSetRows('EntryPoints')), 229)
+        self.assertEqual(len(vw.getVaSetRows('EntryPoints')), 230)
 
     def test_basic_apis(self):
         '''
@@ -463,17 +463,17 @@ class VivisectTest(unittest.TestCase):
         self.assertTrue(len(vw.getLocations()) > 76000)
 
         # tuples are Name, Number of Locations, Size in bytes, Percentage of space
-        ans = {0: ('Undefined', 0, 70828, 18),
+        ans = {0: ('Undefined', 0, 55596, 14),
                1: ('Num/Int',   715, 3703, 0),
                2: ('String',    265, 6485, 1),
                3: ('Unicode',   174, 5596, 1),
                4: ('Pointer',   361, 2888, 0),
-               5: ('Opcode',    72507, 279377, 71),
+               5: ('Opcode',    72507, 279377, 73),
                6: ('Structure', 1018, 12740, 3),
                7: ('Clsid',     0, 0, 0),
                8: ('VFTable',   0, 0, 0),
                9: ('Import Entry', 370, 2960, 0),
-               10: ('Pad',      865, 8639, 2)}
+               10: ('Pad',      864, 8511, 2)}
         dist = vw.getLocationDistribution()
         for loctype, locdist in dist.items():
             self.assertEqual(locdist, ans[loctype])
@@ -584,6 +584,14 @@ class VivisectTest(unittest.TestCase):
         for va, disp in ans:
             self.assertEqual(disp, vw.reprVa(va))
 
+    def test_basic_reloc(self):
+        vw = self.chgrp_vw
+        rloc = vw.addRelocation(0xdeadbeef, v_const.RTYPE_BASEOFF)
+        self.assertIsNone(rloc)
+
+        rloc = vw.addRelocation(0x08054184, v_const.RTYPE_BASEPTR)
+        self.assertIsNotNone(rloc)
+
     def test_naughty(self):
         '''
         Test us some error conditions
@@ -1143,12 +1151,12 @@ class VivisectTest(unittest.TestCase):
             'PE_Header': (0x140000000, 0x1000, e_memory.MM_READ),
             '.text': (0x140001000, 0x49000, e_memory.MM_READ | e_memory.MM_EXEC),
             '.rdata': (0x14004a000, 0xc000, e_memory.MM_READ),
-            '.data': (0x140056000, 0x3000, e_memory.MM_READ | e_memory.MM_WRITE),
+            '.data': (0x140056000, 0x2a00, e_memory.MM_READ | e_memory.MM_WRITE),
             '.pdata': (0x140059000, 0x3000, e_memory.MM_READ),
-            '.00cfg': (0x14005c000, 0x1000, e_memory.MM_READ),
-            '.freestd': (0x14005d000, 0x1000, e_memory.MM_READ),
-            '.tls': (0x14005e000, 0x1000, e_memory.MM_READ | e_memory.MM_WRITE),
-            '.reloc': (0x140092000, 0x1000, e_memory.MM_READ),
+            '.00cfg': (0x14005c000, 0x200, e_memory.MM_READ),
+            '.freestd': (0x14005d000, 0x200, e_memory.MM_READ),
+            '.tls': (0x14005e000, 0x200, e_memory.MM_READ | e_memory.MM_WRITE),
+            '.reloc': (0x140092000, 0x400, e_memory.MM_READ),
         }
         for sva, ssize, sname, sfname in vw.getSegments():
             self.assertEqual(ans[sname][0], sva)
@@ -1175,6 +1183,12 @@ class VivisectTest(unittest.TestCase):
         self.assertEqual(str(op), 'mov rax,qword [rsi + 56]')
         self.assertEqual(len(vw._op_cache), 1)
 
+    def test_string_without_termination(self):
+        vw = self.firefox_vw
+        vw.addMemoryMap(0x2000, 7, 'test', b'this is a string that never terminates.')
+        vw.makeString(0x2000)
+        self.assertEqual(vw.readMemString(0x2000), b'this is a string that never terminates.')
+
     def test_function_thunks(self):
         vw = self.firefox_vw
 
